<?php

/**
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * @package openEngine
 * @author Stephan Raabe
 */

class Export
{
	private $db;
	private $prefix;
	private $page;
	private $user; 
	private $dialog;
	private $adminLang;
	private $nav;
	private $set;
	private $clean_list;
	private $export_match;
	private $export_replace;
	private $export_match_use;
	private $export_replace_use;
	private $export_list;
	
	/**
	 * Konstruktor
	 *
	 * @return Export
	 */
	public function Export()
	{
		global $oe_db,$db_praefix,$oe_page,$oe_user,$oe_dialog,$admin_lang,$oe_nav,$oe_set;
		$this->db = $oe_db;
		$this->prefix = $db_praefix;
		$this->page = $oe_page;
		$this->user = $oe_user;
		$this->dialog = $oe_dialog;
		$this->nav = $oe_nav;
		$this->adminLang = $admin_lang;
		$this->set = $oe_set;
		$this->clean_list = array();
		$this->export_match = array();
		$this->export_replace = array();
		$this->export_match_use = array();
		$this->export_replace_use = array();
		$this->export_list = array();
		$this->export_list_use = array();
	}
	
	/**
	 * Verarbeitung der AJAX Aufrufe
	 *
	 */
	public function setAjax()
	{
		if (isset($_GET["method"]))
		{
			switch ($_GET["method"])
			{
				case "checkExport":
					$this->checkExport();	
				break;

				case "getExportFiles":
					$this->getExportFiles($_GET["mode"]);
				break;
						
				case "startExport":
					$this->startExport();
				break;
				
				case "updateDate":
					$this->updateDate();
				break;
				
				case "cleanup":
					$this->cleanup();
				break;
			}
		}
	}
	
	/**
	 * berprft das Lesen einer externen Url.
	 * Schreibt 0 bei erfolgreichem Lesen.
	 *
	 */
	private function checkExport()
	{
		$site_url = $this->set->getSiteUrl();
		if ($this->set->getSiteAuthUrl() != "")
		{
			$site_url = $this->set->getSiteAuthUrl();
		}
		$test_url = $site_url."/system/exporting/test_export.php";
		$content = @file_get_contents($test_url);
		if ($content == "openEngine - Export OK")
		{		
			echo "0";				
		}
		else
		{
			echo "1";
		}						
	}
	
	/**
	 * Bestimmmt die zu exportierenden Dateien und die Clean-Liste. 
	 * Das Ergebnis wird als HTML an das Interface zurckgegeben.
	 * Die Session wird genutzt um die ermittelten Informationen zu speichern. 
	 *
	 * @param int $mode Exportmodus
	 */
	private function getExportFiles($mode)
	{
		$this->getExportSites($mode);
		$this->ajaxFilelist();
		$this->writeSession();
	}
	
	/**
	 * Schreibt die Export-Arrays in die Session.
	 *
	 */
	private function writeSession()
	{
		$export_list_use = array();
		foreach ($this->export_list as $value)
		{
			$arr_temp = array();
			$arr_temp["page_key"] = $value["page_key"];
			$arr_temp["page_exportfolder"] = $value["page_exportfolder"];
			$arr_temp["page_path"] = $value["page_path"];
			$arr_temp["page_exportmd5"] = $value["page_exportmd5"];
			$arr_temp["page_exportdate"] = $value["page_exportdate"];
			$arr_temp["export_mode"] = $value["export_mode"];
			array_push($export_list_use, $arr_temp);
		}
		$_SESSION["export_list"] = $export_list_use;		
		$this->exportReplaces();
		$_SESSION["export_match"] = $this->export_match;
		$_SESSION["export_replace"] = $this->export_replace;
		$_SESSION["clean_list"] = $this->clean_list;		
	}
	
	/**
	 * Aktualisiert das Datum einer Seite.
	 *
	 */
	private function updateDate()
	{
		global $page;
		$oe_changedate = new Changedate();
		$oe_changedate->update($page["page_key"],true);
	}
		
	/**
	 * Startet den statischen Export.
	 * Gibt den aktuellen Exportschritt zurck.
	 * Schreibt "finished", wenn der Export abgeschlossen ist.
	 *
	 */
	private function startExport()
	{
		$step = $_GET['step'];
		$force_deploy = 0;
		if ($_SESSION["account_group"] == 2)
		{
			$force_deploy = $_GET['force_deploy'];
		}
		$export_list_use = $_SESSION["export_list"];
		$this->export_match_use = $_SESSION["export_match"];
		$this->export_replace_use = $_SESSION["export_replace"];		
		if ((($step - 1) * $this->set->getExportStepsize()) < sizeof($export_list_use))
		{
			$export_arr = array_slice($export_list_use,($step-1) * $this->set->getExportStepsize(),$this->set->getExportStepsize());
			foreach ($export_arr as $value)
			{
				$this->exportFile($value,$force_deploy);
			}
			echo $step + 1;
		}
		else
		{
			echo "finished";
		}
	}
	
	/**
	 * Ermittelt die Exportersetzungen.
	 *
	 */
	private function exportReplaces()
	{
		$query = "SELECT page_key,page_path,LENGTH(page_path) as str FROM ".$this->prefix."page WHERE page_status = 0 AND page_lockexport = 0 ORDER BY str DESC";
		$resArr = $this->db->select($query);
		foreach ($resArr as $row)
		{
			$page_path_file = $this->page->getFile($row["page_path"]);
			array_push($this->export_match,"website.php?id=".$row["page_path"]);
			array_push($this->export_replace,$page_path_file);
		}
		$result_replacings = $this->page->getReplacings();
		foreach ($result_replacings as $row)
		{
			array_push($this->export_match,$row["re_name"]);
			array_push($this->export_replace,$row["re_value"]);
		}
	}

	/**
	 * Lscht nicht mehr bentigte Dateien
	 *
	 */
	private function cleanup()
	{
		$clean_list = $_SESSION["clean_list"];
		foreach ($clean_list as $value)
		{
			if ($this->user->pagePermission($value["page_key"]))
			{
				$page_file = $this->getFilename($value["page_path"]);
				$folderPath = $this->getFolder($value["page_path"]);
				$dest = $value["page_exportfolder"].$folderPath.$page_file;
				$destxml = $value["page_exportfolder"]."/xml".$folderPath.$page_file.".xml";
				if (file_exists($dest))
				{
					unlink($dest);
				}
				if (file_exists($destxml))
				{
					unlink($destxml);
				}
				$param = array("page_key" => $value["page_key"]);
				$query = "UPDATE ".$this->prefix."page SET page_exportdelete = 1 WHERE page_key = :page_key";
				$this->db->update($query,$param);
			}
		}
		$_SESSION["export_list"] = "";		
		$_SESSION["export_match"] = "";
		$_SESSION["export_replace"] = "";		
		$_SESSION["clean_list"] = "";		
		echo "cleanup";
	}
	
	/**
	 * Exportiert eine Seite. 
	 * Je nach Wert von $export_page["export_mode"] werden unterschiedliche Vorgnge gestartet.
	 *
	 * @param array $export_page Array mit Seiteninformationen
	 * @param int $force_deploy 	0: kein Force-Deploy
	 * 								1: Force-Deploy
	 */
	private function exportFile($export_page,$force_deploy)
	{
		if ($force_deploy == 1)
		{
			$export_page["page_exportdate"] = date("Y-m-d H:i:s");
		}
		switch ($export_page["export_mode"])
		{
			case 0:
			$this->exportHTML($export_page);
			break;
			
			case 2:
			$this->exportXML($export_page);
			break;

			case 3:
			$this->exportHTML($export_page);
			$this->exportXML($export_page);
			break;
				
			case 4:
			$this->exportRSS($export_page);
			break;
		}
	}
	
	/**
	 * Exportiert eine HTML Seite
	 *
	 * @param array $export_page Array mit Seiteninformationen
	 */
	private function exportHTML($export_page)
	{
		$site_url = $this->siteUrl();
		$content = @file_get_contents($site_url."/website.php?id=".$export_page["page_path"]."&export=yes");
		$page_file = $this->getFilename($export_page["page_path"]);
		$folderPath = $this->getFolder($export_page["page_path"]);
		$dest = $export_page["page_exportfolder"].$folderPath;
		$this->dialog->mk_dir($this->getFolderPath($export_page["page_path"],$export_page["page_exportfolder"]));
		$content = $this->replaceContent($export_page["page_path"],$content);
		$page_exportdate = $this->updateExportdate($export_page["page_path"],$export_page["page_exportdate"],$export_page["page_exportmd5"],$content);
		$this->writeFile($dest,$page_file,$export_page["page_key"],$content,$page_exportdate);		
	}

	/**
	 * Exportiert eine XML Seite 
	 *
	 * @param array $export_page Array mit Seiteninformationen
	 */
	private function exportXML($export_page)
	{
		$currentpage = $this->page->getPageKey($export_page["page_key"]);
		$page_xmlcontent = $this->replaceContentXML($currentpage["page_xmlcontent"],$export_page["page_exportfolder"]);
		$destxml = $export_page["page_exportfolder"]."/xml".$this->getFolder($export_page["page_path"]);
		$page_file = $this->getFilename($export_page["page_path"]);
		if (file_exists($export_page["page_exportfolder"]."/xml"))
		{
			$this->dialog->mk_dir($this->getFolderPath($export_page["page_path"],$export_page["page_exportfolder"]."/xml"));
		}
		$this->writeXML($destxml,$page_file,$page_xmlcontent,$export_page["page_exportdate"]);		
	}
	
	/**
	 * Exportiert ein RSS Newsfeed
	 *
	 * @param array $export_page Array mit Seiteninformationen
	 */
	private function exportRSS($export_page)
	{
		global $site_encoding;
		$site_url = $this->siteUrl();
		$page_path = $export_page["page_path"];
		$page_exportdate = $export_page["page_exportdate"];
		$export_folder = $export_page["page_exportfolder"];
		$page_file = $this->replaceFileName($this->page->getFile($page_path));
		$content = @file_get_contents($site_url."/website.php?id=".$page_path."&rss=1&export=yes");
		$content = str_replace($this->export_match_use, $this->export_replace_use, $content);
		$fp = fopen($export_folder."/".$page_file, "w+");
		if ($site_encoding == "utf-8")
		{	
			fwrite($fp, pack("CCC",0xef,0xbb,0xbf));
		}
		fputs($fp,$content);
		fclose($fp);
		touch($export_folder."/".$page_file,strtotime($page_exportdate));		
	}
	
	/**
	 * Fhrt Dateinamen-Ersetzungen in einem Pfad fr RSS-Export aus.
	 *
	 * @param string $page_file Dateiname
	 * @return string Dateiname
	 */
	private function replaceFileName($page_file)
	{
		$page_file = str_replace(".htm","",$page_file);
		$page_file = str_replace(".xml","",$page_file);
		$page_file = str_replace(".php","",$page_file);
		$page_file = str_replace(".html","",$page_file);
		$page_file = str_replace(".jsp","",$page_file);
		$page_file = str_replace(".asp","",$page_file);
		$page_file = str_replace(".aspx","",$page_file);
		return $page_file."_rss.xml";		
	}
	
	/**
	 * Ermittelt die Url der Web-Site. Dabei wird auch eine angegebene HTTPS-Adresse bercksichtigt.
	 *
	 * @return string Site-Url
	 */
	private function siteUrl()
	{
		$site_url = $this->set->getSiteUrl();
		if ($this->set->getSiteAuthUrl() != "")
		{
			$site_url = $this->set->getSiteAuthUrl();
		}
		return $site_url;
	}
	
	/**
	 * Ermittelt Informationen einer Seite.
	 *
	 * @param int $page_key ID der Seite
	 * @return array Array mit Seiteninformationen
	 */
	private function getPageRow($page_key)
	{
		$param = array("page_key" => $page_key);
		$query = "SELECT page_key,page_status,page_lockexport,page_extern,page_path,page_headline,page_template,page_exportmd5,page_exportdate,page_exportdelete,page_exportfolder FROM ".$this->prefix."page WHERE page_key = :page_key";
		$currentpage = $this->db->row($query,$param);
		return $currentpage;		
	}
	
	/**
	 * Ermittelt zur exportierende Seiten.
	 *
	 * @return array Array mit Seiteninformationen
	 */
	private function getPageRowsExport()
	{
		$query = "SELECT page_key,page_status,page_lockexport,page_extern,page_path,page_headline,page_template,page_exportmd5,page_exportdate,page_exportdelete,page_exportfolder FROM ".$this->prefix."page WHERE page_forceexport = 1 AND page_status = 0";
		return $this->db->select($query);
	}
	
	/**
	 * Ermittelt den Dateinamen aufgrund eines Pfades.
	 *
	 * @param string $page_path Seitenpfad mit Dateinamen
	 * @return string Dateiname
	 */
	private function getFilename($page_path)
	{
		$matchArr = explode("/",$page_path);
		$page_file = $matchArr[sizeof($matchArr) - 1];
		return $page_file;		
	}
	
	/**
	 * Ermittelt die Ordnerstruktur ohne Dateinamen.
	 *
	 * @param string $page_path Seitenpfad
	 * @return string Pfad
	 */
	private function getFolder($page_path)
	{
		$folder_name = str_replace($this->getFilename($page_path),"",$page_path);
		return $folder_name;
	}
	
	/**
	 * Ermittelt die Pfad-Tiefe.
	 *
	 * @param string $page_path Seitenpfad
	 * @return int Ebenentiefe
	 */
	private function getPathDepth($page_path)
	{
		$matchArr = explode("/",$page_path);
		return sizeof($matchArr);
	}
	
	/**
	 * Ermittelt den Serverpfad aufgrund des Seitenpfads
	 *
	 * @param string $page_path Seitenpfad
	 * @param string $export_folder Export-Ordner
	 * @return string Serverpfad
	 */
	private function getFolderPath($page_path,$export_folder)
	{
		$fc = $_SERVER["SCRIPT_FILENAME"];
		$fc = str_replace("\\","/",$fc);
		$fc = str_replace("/cms/website.php","",$fc);
		$fe = str_replace("../","",$export_folder);
		$fp = $fc."/".$fe.$this->getFolder($page_path);
		return $fp;
	}
	
	/**
	 * Ermittelt aufgrund eines Seitenpfads den entsprechenden relativen Pfad
	 *
	 * @param string $page_path 
	 * @return string Relativer Pfad
	 */
	private function getRelativeLink($page_path)
	{
		$relLink = "";
		for ($i = 1; $i < $this->getPathDepth($page_path) - 1; $i++)
		{
			$relLink .= "../";
		}
		if ($relLink != "")
		{
			$relLink = substr($relLink,0,strlen($relLink) - 1);
		}
		return $relLink;		
	}
	
	/**
	 * Ermittelt den absoluten Pfad des Exportordners
	 *
	 * @param string $ef Exportordner
	 * @return string Absoluter Pfad des Exportordners
	 */
	private function getAbsoluteExportfolder($ef)
	{
		$ef = str_replace("../","",$ef);
		$ef = str_replace("./","",$ef);
		if (substr($ef,0,1) != "/")
		{
			$ef = "/".$ef;
		}
		return $ef;		
	}
	
	/**
	 * Nimmt in der eingelesenen Seite Exportersetzungen vor.
	 *
	 * @param string $page_path Seitenpfad
	 * @param string $content Seiteninhalt
	 * @return string Seiteninhalt mit durchgefhrten Ersetzungen
	 */
	private function replaceContent($page_path,$content)
	{
		$relLink = $this->getRelativeLink($page_path);
		$content = str_replace("website.php?id=",$relLink,$content);
		$result_replacings = $this->page->getReplacings();
		foreach ($result_replacings as $row)
		{
			$content = str_replace($row["re_name"],$relLink."/".$row["re_value"],$content);			
		}
		return $content;
	}

	/**
	 * Nimmt in der eingelesenen Seite Exportersetzungen fr XML vor.
	 *
	 * @param string Seiteninhalt XML
	 * @param string Exportordner
	 * @return string Seiteninhalt XML mit durchgefhrten Ersetzungen
	 */
	private function replaceContentXML($content,$export_folder)
	{
		$export_folder = $this->getAbsoluteExportfolder($export_folder);
		$content = str_replace("website.php?id=",$export_folder,$content);
		$site_pool = $this->set->getSitePool();
		$site_pool_new = $this->getAbsoluteExportfolder($site_pool);
		$content = str_replace($site_pool,$site_pool_new,$content);		
		return $content;
	}
	
	/**
	 * Aktualisiert das Exportdatum einer Seiten
	 *
	 * @param string $page_path Seitenpfad
	 * @param date $page_exportdate Exportdatum
	 * @param string $page_exportmd5 MD5 Kodierung des Seiteninhalts
	 * @param string $content Seiteninhalt
	 * @return date Datum
	 */
	private function updateExportdate($page_path,$page_exportdate,$page_exportmd5,$content)
	{
		$page_exportmd5_new = md5($content);
		if ($page_exportmd5 != $page_exportmd5_new)
		{
			$page_exportdate = date("Y-m-d H:i:s");
			$param = array("page_exportdate" => $page_exportdate, "page_path" => $page_path);
			$query = "UPDATE ".$this->prefix."page SET page_exportdate = :page_exportdate WHERE page_path = :page_path";
			$this->db->update($query,$param);
		}
		$param = array("page_exportmd5" => $page_exportmd5_new, "page_path" => $page_path);
		$query = "UPDATE ".$this->prefix."page SET page_exportmd5 = :page_exportmd5 WHERE page_path = :page_path";
		$this->db->update($query,$param);
		return $page_exportdate;
	}
	
	/**
	 * Schreibt die zu exportierende Seite auf den Server.
	 *
	 * @param string $dest Exportziel
	 * @param string $file_name Dateiname
	 * @param int $page_key ID der Seite
	 * @param string $content Seiteninhalt
	 * @param date $page_exportdate Exportdatum
	 */
	private function writeFile($dest,$file_name,$page_key,$content,$page_exportdate)
	{
		global $site_encoding;
		if (file_exists($dest))
		{
			$fp = fopen($dest.$file_name, "w+");
			if ($site_encoding == "utf-8")
			{	
				fwrite($fp, pack("CCC",0xef,0xbb,0xbf));
			}
			fputs($fp,$content);
			fclose($fp);
			if (file_exists($dest.$file_name))
			{
				touch($dest.$file_name,strtotime($page_exportdate));
			}
			$param = array("page_key" => $page_key);
			$query = "UPDATE ".$this->prefix."page SET page_exported = 1,page_exportdelete = 0 WHERE page_key = :page_key";
			$this->db->update($query,$param);
		}
	}

	/**
	 * Schreibt die zu exportierende XML-Datei auf den Server.
	 *
	 * @param string $dest Exportziel
	 * @param string $file_name Dateiname
	 * @param string $content Seiteninhalt
	 * @param date $page_exportdate Exportdatum
	 */
	private function writeXML($dest,$file_name,$content,$page_exportdate)
	{
		global $site_encoding;
		if (file_exists($dest))
		{
			$fp = fopen($dest.$file_name.".xml", "w+");
			if ($site_encoding == "utf-8")
			{	
				fwrite($fp, pack("CCC",0xef,0xbb,0xbf));
			}
			fputs($fp,$content);
			fclose($fp);
			if (file_exists($dest.$file_name.".xml"))
			{
				touch($dest.$file_name.".xml",strtotime($page_exportdate));
			}
		}
	}

	/**
	 * Stellt die zu exportierenden Seiten zusammen und speichert diese in Arrays
	 *
	 * @param int $mode Exportmodus
	 */
	private function getExportSites($mode)
	{
		global $page,$path;
		switch ($mode)
		{
			case 1:
			$this->getExFiles($path[0]["page_key"],$path[0]["page_exportfolder"]);
			break;
	
			case 2:
			$export_start_page = $this->getPageRow($path[0]["page_key"]); 
			$export_page = $this->getPageRow($page["page_key"]);
			$export_page["page_exportfolder"] = $export_start_page["page_exportfolder"];
			$param = array("template_name" => $export_page["page_template"]);
			$query = "SELECT template_lockexport FROM ".$this->prefix."template WHERE template_name = :template_name";
			$tempArr = $this->db->row($query,$param);
			if ($tempArr["template_lockexport"] != 1)
			{
				$export_page["export_mode"] = $tempArr["template_lockexport"];
				array_push($this->export_list,$export_page);
			}			
			break;
	
			case 3:
			$export_start_page = $this->getPageRow($path[0]["page_key"]); 
			$this->getExFiles($page["page_key"],$export_start_page["page_exportfolder"]); 
			break;
	
			case 4:
			$query = "SELECT page_key,page_exportfolder FROM ".$this->prefix."page WHERE page_parent = 0";
			$resArr = $this->db->select($query);
			foreach ($resArr as $row)
			{
				$this->getExFiles($row["page_key"],$row["page_exportfolder"]);
			} 
			break;
			
			case 5:
			$export_start_page = $this->getPageRow($path[0]["page_key"]); 
			$export_page = $this->getPageRow($page["page_key"]);
			$export_page["page_exportfolder"] = $export_start_page["page_exportfolder"];			
			$param = array("template_name" => $export_page["page_template"]);
			$query = "SELECT template_lockexport FROM ".$this->prefix."template WHERE template_name = :template_name";
			$tempArr = $this->db->row($query,$param);
			if ($tempArr["template_lockexport"] != 1)
			{
				$export_page["export_mode"] = $tempArr["template_lockexport"];
				array_push($this->export_list,$export_page);
			}			
			if ($page["page_parent"] != 0)
			{
				$export_page = $this->getPageRow($page["page_parent"]);
				$param = array("template_name" => $export_page["page_template"]);
				$query = "SELECT template_lockexport FROM ".$this->prefix."template WHERE template_name = :template_name";
				$tempArr = $this->db->row($query,$param);
				if ($tempArr["template_lockexport"] != 1)
				{
					$export_page["export_mode"] = $tempArr["template_lockexport"];
					array_push($this->export_list,$export_page);
				}				
			}
			break;
		}
		$this->updatePermission();
		$this->updateForceexport(); 
		$this->updateRSSexport();
	}
	
	/**
	 * Zusammenstellung der Export- und Clean-Liste
	 *
	 * @param int ID der Seite
	 * @param string Exportordner
	 */
	private function getExFiles($page_key,$page_exportfolder)
	{
		$export_start_page = $this->getPageRow($page_key);
		$export_start_page["page_exportfolder"] = $page_exportfolder;
		$param = array("template_name" => $export_start_page["page_template"]);
		$query = "SELECT * FROM ".$this->prefix."template WHERE template_name = :template_name";
		$tempArr = $this->db->row($query,$param);
		$export_start_page["export_mode"] = $tempArr["template_lockexport"];
		if (($export_start_page["page_status"] == 0) && ($export_start_page["page_lockexport"] == 0) && ($export_start_page["page_extern"] == "") && ($tempArr["template_lockexport"] != 1))
		{
			array_push($this->export_list,$export_start_page);
		}
		else 
		{
			if ($export_start_page["page_exportdelete"] == 0)
			{
				array_push($this->clean_list,$export_start_page);
			}
		}
		$param = array("page_parent" => $page_key);
		$query = "SELECT page_key FROM ".$this->prefix."page WHERE page_parent = :page_parent";
		$resArr = $this->db->select($query,$param);
		foreach ($resArr as $row)
		{
			$this->getExFiles($row["page_key"],$page_exportfolder);
		}
	}
	
	/**
	 * Aktualisiert die Exportliste auf Basis der Seitenbereichtigungen. 
	 *
	 */
	private function updatePermission()
	{
		$export_list_new = array();
		foreach ($this->export_list as $index => $value)
		{
			if ($this->user->pagePermission($value["page_key"]))
			{
				array_push($export_list_new,$this->export_list[$index]);
			}
		}
		$this->export_list = $export_list_new;
	}
	
	/**
	 * Aktualisiert die Exportliste auf Basis der eingestellten erzwungenen Exporte.
	 *
	 */
	private function updateForceexport()
	{
		foreach ($this->getPageRowsExport() as $row)
		{
			$force = true; 
			foreach ($this->export_list as $value)
			{
				if ($row["page_key"] == $value["page_key"])
				{
					$force = false; 
				}
			}
			if ($force)
			{
				$parent_pages = $this->page->getParentPages($row["page_key"]);
				$export_start_page = $this->getPageRow($parent_pages[0]);
				$row["page_exportfolder"] = $export_start_page["page_exportfolder"];
				$param = array("template_name" => $row["page_template"]);
				$query = "SELECT template_lockexport FROM ".$this->prefix."template WHERE template_name = :template_name";
				$tempArr = $this->db->row($query,$param);
				if ($tempArr["template_lockexport"] != 1)
				{
					$row["export_mode"] = $tempArr["template_lockexport"];
					array_push($this->export_list,$row);
				}
			}
		}
	}
		
	/**
	 * Aktualisiert die Exportliste auf Basis der definierten RSS Exporte.
	 *
	 */
	private function updateRSSexport()
	{
		$query = "SELECT * FROM ".$this->prefix."rss inner join ".$this->prefix."page on (".$this->prefix."rss.page_key = ".$this->prefix."page.page_key) WHERE page_status = 0 AND rss_export = 1";
		$resArr = $this->db->select($query);
		foreach ($resArr as $row)
		{
			$parent_pages = $this->page->getParentPages($row["page_key"]);
			$export_start_page = $this->getPageRow($parent_pages[0]);
			$row["page_exportfolder"] = $export_start_page["page_exportfolder"];
			$row["page_headline"] = "[RSS EXPORT] ".$row["page_headline"];
			$row["export_mode"] = 4;
			array_push($this->export_list,$row);
		}
	}

	/**
	 * Schreibt die Exportliste fr das Formular in die Ausgabe.
	 *
	 */
	private function ajaxFilelist()
	{
		global $site_encoding;
		echo '<p class="adminText" id="filelist" count="'.sizeof($this->export_list).'">';
		foreach ($this->export_list as $value) 
		{ 
			if ($site_encoding != "utf-8")
			{
				$headline = $value["page_headline"];
			}
			else 
			{
				$headline = utf8_decode($value["page_headline"]);
			}
			$headline = substr(str_replace('"',"",strip_tags($headline)),0,30);
			echo $headline.' ['.$value["page_key"].'] - '.$value["page_path"].'<br>';
		}
		foreach ($this->clean_list as $value) 
		{ 
			if ($site_encoding != "utf-8")
			{
				$headline = $value["page_headline"];
			}
			else 
			{
				$headline = utf8_decode($value["page_headline"]);
			}
			$headline = "[DELETE] ".substr(str_replace('"',"",strip_tags($headline)),0,30);
			echo $headline.' ['.$value["page_key"].'] - '.$value["page_path"].'<br>';
		}		
		echo "</p>";
	}		
}
?>