<?php

/**
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * @package openEngine
 * @author Stephan Raabe
 */

class Thumbnail
{
	private $set;
	private $db;
		
	/**
	 * Konstruktor
	 *
	 * @return Thumbnail
	 */
	public function Thumbnail()
	{
		global $oe_set,$oe_db;
		$this->set = $oe_set;
		$this->db = $oe_db;
	}

	/**
	 * Erstellt ein Thumbnail
	 *
	 * @param string $filename Kompletter Pfad der Ursprungdatei
	 * @param int $width Breite in Pixel
	 * @param int $height Hhe in Pixel
	 */
	public function createThumbnail($original,$dest = "",$width,$height,$name = "")
	{
		$extension = $this->getFiletype($original);
		if (($extension == "png") || ($extension == "jpg") || ($extension == "gif"))
		{
			if ($this->checkGD($extension))
			{
				if ($dest == "")
				{
					if ($name == "")
					{
						$name = rand(11111111,99999999);	
					}
					$destination = $this->getFileFolder($original).$name.$this->getFilename($original);
				}
				else
				{
					$destination = $dest;
				}
				$this->deleteOldFile($destination);
				$this->create_thumbnail($original,$destination,$width,$height);
				return true;
			}
			else
			{
				return false;
			}
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * Ermittelt den Dateiname
	 *
	 * @param string $p Kompletter Pfad inkl. Dateinamen
	 * @return string Dateiname ohne Pfad
	 */
	private function getFilename($p)
	{
		$pArr = explode("/",$p);
		return $pArr[sizeof($pArr) - 1];
	}
	
	/**
	 * Ermittelt den Ordner einer Datei
	 *
	 * @param string $p Pfad inkl. Dateinamen
	 * @return string Pfad ohne Dateinamen
	 */
	private function getFileFolder($p)
	{
		return str_replace($this->getFilename($p),"",$p);
	}
	
	/**
	 * Enter description here...
	 *
	 * @param unknown_type $filename
	 * @return unknown
	 */
	private function getFiletype($filename)
	{
		$path_parts = pathinfo($filename);
		$extension = strtolower($path_parts["extension"]);
		return $extension;
	}
	
	/**
	 * Lscht ein altes Thumbnail, wenn es existiert
	 *
	 * @param string Kompletter Pfad zur Zieldatei
	 */
	private function deleteOldFile($filename)
	{
		if (file_exists($filename))
		{
			unlink($filename);
		}
	}
	
	/**
	 * Prft, ob die GD Library fr den entsprechenden Dateityp aktiviert ist.
	 *
	 * @param string $t Dateityp (GIF,JPG,PNG)
	 * @return bool Status GD Library fr entsprechenden Dateityp
	 */
	private function checkGD($t)
	{
		$gd = false;
		if (function_exists("ImageTypes"))
		{
			if (($t == "png") && (ImageTypes() & IMG_PNG)) 
			{ 
				$gd = true; 
			}
			if (($t == "jpg") && (ImageTypes() & IMG_JPG)) 
			{ 
				$gd = true; 
			}
			if (($t == "gif") && (ImageTypes() & IMG_GIF)) 
			{
				$gd = true; 
			}
		}
		return $gd;
	}
	
	/**
	 * Enter description here...
	 *
	 * @param unknown_type $infile
	 * @param unknown_type $outfile
	 * @param unknown_type $maxw
	 * @param unknown_type $maxh
	 * @param unknown_type $stretch
	 * @return unknown
	 */
	public function create_thumbnail($infile,$outfile,$maxw,$maxh,$stretch = FALSE) 
	{
	  clearstatcache();
	  if (!is_file($infile)) {
	    trigger_error("Cannot open file: $infile",E_USER_WARNING);
	    return FALSE;
	  }
	  if (is_file($outfile)) {
	      trigger_error("Output file already exists: $outfile",E_USER_WARNING);
	    return FALSE;
	  }
	
	  $functions = array(
	    'image/png' => 'ImageCreateFromPng',
	    'image/jpeg' => 'ImageCreateFromJpeg',
		'image/pjpeg' => 'ImageCreateFromJpeg',
	  );
	
	  // Add GIF support if GD was compiled with it
	  if (function_exists('ImageCreateFromGif')) { $functions['image/gif'] = 'ImageCreateFromGif'; }
	
	  $size = getimagesize($infile);
	
	  // Check if mime type is listed above
	  if (!$function = $functions[$size['mime']]) {
	      trigger_error("MIME Type unsupported: {$size['mime']}",E_USER_WARNING);
	    return FALSE;
	  }
	
	  // Open source image
	  if (!$source_img = $function($infile)) {
	      trigger_error("Unable to open source file: $infile",E_USER_WARNING);
	    return FALSE;
	  }
	
	  $save_function = "image" . strtolower(substr(strrchr($size['mime'],'/'),1));
	
	  // Scale dimensions
	  list($neww,$newh) = $this->scale_dimensions($size[0],$size[1],$maxw,$maxh,$stretch);
	
	  if ($size['mime'] == 'image/png') {
	    // Check if this PNG image is indexed
	    $temp_img = imagecreatefrompng($infile);
	    if (imagecolorstotal($temp_img) != 0) {
	      // This is an indexed PNG
	      $indexed_png = TRUE;
	    } else {
	      $indexed_png = FALSE;
	    }
	    imagedestroy($temp_img);
	  }
	  
	  // Create new image resource
	  if ($size['mime'] == 'image/gif' || ($size['mime'] == 'image/png' && $indexed_png)) {
	    // Create indexed 
	    $new_img = imagecreate($neww,$newh);
	    // Copy the palette
	    imagepalettecopy($new_img,$source_img);
	    
	    $color_transparent = imagecolortransparent($source_img);
	    if ($color_transparent >= 0) {
	      // Copy transparency
	      imagefill($new_img,0,0,$color_transparent);
	      imagecolortransparent($new_img, $color_transparent);
	    }
	  } else {
	    $new_img = imagecreatetruecolor($neww,$newh);
	  }
	  
	  // Copy and resize image
	  imagecopyresampled($new_img,$source_img,0,0,0,0,$neww,$newh,$size[0],$size[1]);
	
	  // Save output file
	  if ($save_function == 'imagejpeg') {
	      // Change the JPEG quality here
	      if (!$save_function($new_img,$outfile,75)) {
	          trigger_error("Unable to save output image",E_USER_WARNING);
	          return FALSE;
	      }
	  } else {
	      if (!$save_function($new_img,$outfile)) {
	          trigger_error("Unable to save output image",E_USER_WARNING);
	          return FALSE;
	      }
	  }
	
	  // Cleanup
	  imagedestroy($source_img);
	  imagedestroy($new_img);
	
	  return TRUE;
	}

	/**
	 * Enter description here...
	 *
	 * @param unknown_type $w
	 * @param unknown_type $h
	 * @param unknown_type $maxw
	 * @param unknown_type $maxh
	 * @param unknown_type $stretch
	 * @return unknown
	 */
	private function scale_dimensions($w,$h,$maxw,$maxh,$stretch = FALSE) 
	{
	    if (!$maxw && $maxh) {
	      // Width is unlimited, scale by width
	      $newh = $maxh;
	      if ($h < $maxh && !$stretch) { $newh = $h; }
	      else { $newh = $maxh; }
	      $neww = ($w * $newh / $h);
	    } elseif (!$maxh && $maxw) {
	      // Scale by height
	      if ($w < $maxw && !$stretch) { $neww = $w; }
	      else { $neww = $maxw; }
	      $newh = ($h * $neww / $w);
	    } elseif (!$maxw && !$maxh) {
	      return array($w,$h);
	    } else {
	      if ($w / $maxw > $h / $maxh) {
	        // Scale by height
	        if ($w < $maxw && !$stretch) { $neww = $w; }
	        else { $neww = $maxw; }
	        $newh = ($h * $neww / $w);
	      } elseif ($w / $maxw <= $h / $maxh) {
	        // Scale by width
	        if ($h < $maxh && !$stretch) { $newh = $h; }
	        else { $newh = $maxh; }
	        $neww = ($w * $newh / $h);
	      }
	    }
	    return array(round($neww),round($newh));
	}	
}